@@ -42,11 +42,9 @@ impl SystemEnv {
                 val.v = v;
             }
         };
-        if let Ok(out) = Command::new("rustup").arg("default").output() {
-            update_val(
-                RUST_CHANNEL,
-                String::from_utf8(out.stdout)?.trim().to_string(),
-            );
+
+        if let Some(v) = std_env.get("RUSTUP_TOOLCHAIN") {
+            update_val(RUST_CHANNEL, v.to_string());
         }
 
         if let Ok(out) = Command::new("rustc").arg("-V").output() {
@@ -179,7 +177,7 @@ mod dep_source_replace {
         } else {
             (DEP_REPLACE_NONE, input.len())
         };
-        format!("{}{}", input[..index].to_string(), val)
+        format!("{}{}", &input[..index], val)
     }
 
     pub fn filter_cargo_tree(lines: Vec<&str>) -> String {
